@@ -9,9 +9,9 @@
 #include "contacteditordialog.h"
 
 #include "contacteditor.h"
-
 #include <Akonadi/CollectionComboBox>
 #include <Akonadi/Item>
+#include <kwidgetsaddons_version.h>
 
 #include <KContacts/Addressee>
 
@@ -27,7 +27,10 @@
 #include <QVBoxLayout>
 
 using namespace Akonadi;
-
+namespace
+{
+static const char myContactEditorDialogDialogGroupName[] = "ContactEditor";
+}
 class Akonadi::ContactEditorDialogPrivate
 {
 public:
@@ -109,7 +112,7 @@ public:
     void readConfig()
     {
         KConfig config(QStringLiteral("akonadi_contactrc"));
-        KConfigGroup group(&config, QStringLiteral("ContactEditor"));
+        KConfigGroup group(&config, myContactEditorDialogDialogGroupName);
         const QSize size = group.readEntry("Size", QSize(800, 500));
         if (size.isValid()) {
             q->resize(size);
@@ -119,7 +122,7 @@ public:
     void writeConfig()
     {
         KConfig config(QStringLiteral("akonadi_contactrc"));
-        KConfigGroup group(&config, QStringLiteral("ContactEditor"));
+        KConfigGroup group(&config, myContactEditorDialogDialogGroupName);
         group.writeEntry("Size", q->size());
         group.sync();
     }
@@ -175,12 +178,20 @@ AkonadiContactEditor *ContactEditorDialog::editor() const
 void ContactEditorDialog::accept()
 {
     if (d->mEditor->hasNoSavedData()) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        const int answer = KMessageBox::questionTwoActions(this,
+#else
         const int answer = KMessageBox::questionYesNo(this,
-                                                      i18nc("@info", "Location was not saved. Do you want to close editor?"),
-                                                      i18nc("@title:window", "Confirmation"),
-                                                      KGuiItem(i18nc("@action:button", "Close Editor"), QStringLiteral("dialog-close")),
-                                                      KGuiItem(i18nc("@action:button", "Do Not Close"), QStringLiteral("dialog-cancel")));
+#endif
+                                                           i18nc("@info", "Location was not saved. Do you want to close editor?"),
+                                                           i18nc("@title:window", "Confirmation"),
+                                                           KGuiItem(i18nc("@action:button", "Close Editor"), QStringLiteral("dialog-close")),
+                                                           KGuiItem(i18nc("@action:button", "Do Not Close"), QStringLiteral("dialog-cancel")));
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (answer == KMessageBox::ButtonCode::SecondaryAction) {
+#else
         if (answer == KMessageBox::No) {
+#endif
             return;
         }
     }
@@ -192,15 +203,24 @@ void ContactEditorDialog::accept()
 
 void ContactEditorDialog::reject()
 {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    const int answer = KMessageBox::questionTwoActions(this,
+#else
     const int answer = KMessageBox::questionYesNo(this,
-                                                  i18nc("@info", "Do you really want to cancel?"),
-                                                  i18nc("@title:window", "Confirmation"),
-                                                  KGuiItem(i18nc("@action:button", "Cancel Editing"), QStringLiteral("dialog-ok")),
-                                                  KGuiItem(i18nc("@action:button", "Do Not Cancel"), QStringLiteral("dialog-cancel")));
+#endif
+                                                       i18nc("@info", "Do you really want to cancel?"),
+                                                       i18nc("@title:window", "Confirmation"),
+                                                       KGuiItem(i18nc("@action:button", "Cancel Editing"), QStringLiteral("dialog-ok")),
+                                                       KGuiItem(i18nc("@action:button", "Do Not Cancel"), QStringLiteral("dialog-cancel")));
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (answer == KMessageBox::ButtonCode::PrimaryAction) {
+#else
     if (answer == KMessageBox::Yes) {
+#endif
         QDialog::reject(); // Discard current changes
     }
 }
 
 #include "moc_contacteditordialog.cpp"
+#include <kwidgetsaddons_version.h>
