@@ -11,7 +11,6 @@
 
 #include <KContacts/Addressee>
 #include <KContacts/ContactGroup>
-#include <kcontacts_version.h>
 
 #include <KIconLoader>
 #include <KLocalizedString>
@@ -100,22 +99,14 @@ QVariant ContactsTreeModel::entityData(const Item &item, int column, int role) c
             case HomeAddress: {
                 const KContacts::Address address = contact.address(KContacts::Address::Home);
                 if (!address.isEmpty()) {
-#if KContacts_VERSION < QT_VERSION_CHECK(5, 92, 0)
-                    return address.formattedAddress();
-#else
-                    return address.formatted(KContacts::AddressFormatStyle::MultiLineInternational);
-#endif
+                    return address.formatted(KContacts::AddressFormatStyle::Postal);
                 }
                 break;
             }
             case BusinessAddress: {
                 const KContacts::Address address = contact.address(KContacts::Address::Work);
                 if (!address.isEmpty()) {
-#if KContacts_VERSION < QT_VERSION_CHECK(5, 92, 0)
-                    return address.formattedAddress();
-#else
-                    return address.formatted(KContacts::AddressFormatStyle::MultiLineInternational);
-#endif
+                    return address.formatted(KContacts::AddressFormatStyle::Postal);
                 }
                 break;
             }
