@@ -19,19 +19,23 @@
 #include <Akonadi/EntityDisplayAttribute>
 #include <Akonadi/Item>
 #include <Akonadi/ItemFetchScope>
-#include <KColorScheme>
 #include <KConfigGroup>
 #include <KContacts/Addressee>
-#include <KIOCore/kio/transferjob.h>
 #include <KLocalizedString>
+#include <kio/transferjob.h>
 
+#include <KConfig>
 #include <KContacts/VCardConverter>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <prison/Prison>
+#else
+#include <Prison/Prison>
+#endif
 #include <QGuiApplication>
 #include <QIcon>
 #include <QScreen>
 #include <QUrlQuery>
 #include <QVBoxLayout>
-#include <prison/Prison>
 
 using namespace Akonadi;
 
