@@ -8,12 +8,12 @@
 
 #include "emailaddressselectionmodel.h"
 #include <Akonadi/ChangeRecorder>
-#include <Akonadi/Contact/ContactsTreeModel>
+#include <Akonadi/ContactsTreeModel>
 #include <Akonadi/EntityDisplayAttribute>
 #include <Akonadi/ItemFetchScope>
+#include <Akonadi/Session>
 #include <KContacts/Addressee>
 #include <KContacts/ContactGroup>
-#include <akonadi/session.h>
 
 using namespace Akonadi;
 
@@ -37,9 +37,7 @@ EmailAddressSelectionModel::EmailAddressSelectionModel(QObject *parent)
     mModel = new Akonadi::ContactsTreeModel(changeRecorder, this);
 }
 
-EmailAddressSelectionModel::~EmailAddressSelectionModel()
-{
-}
+EmailAddressSelectionModel::~EmailAddressSelectionModel() = default;
 
 Akonadi::ContactsTreeModel *EmailAddressSelectionModel::model() const
 {
