@@ -13,9 +13,9 @@
 #include <KContacts/Addressee>
 #include <KLineEdit>
 #include <KLocalizedString>
+#include <KUrlRequester>
 #include <QHBoxLayout>
 #include <QStandardPaths>
-#include <kurlrequester.h>
 
 FreeBusyEditWidget::FreeBusyEditWidget(QWidget *parent)
     : QWidget(parent)
@@ -31,9 +31,7 @@ FreeBusyEditWidget::FreeBusyEditWidget(QWidget *parent)
     setFocusPolicy(Qt::StrongFocus);
 }
 
-FreeBusyEditWidget::~FreeBusyEditWidget()
-{
-}
+FreeBusyEditWidget::~FreeBusyEditWidget() = default;
 
 static QString freeBusyUrlStore()
 {
