@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -13,8 +13,6 @@ CustomFielsListWidgetTest::CustomFielsListWidgetTest(QObject *parent)
 {
 }
 
-CustomFielsListWidgetTest::~CustomFielsListWidgetTest()
-{
-}
+CustomFielsListWidgetTest::~CustomFielsListWidgetTest() = default;
 
 QTEST_MAIN(CustomFielsListWidgetTest)
