@@ -2,7 +2,7 @@
     This file is part of Contact Editor.
 
     SPDX-FileCopyrightText: 2010 Tobias Koenig <tokoe@kde.org>
-    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -32,9 +32,7 @@ CustomFieldsListDelegate::CustomFieldsListDelegate(QAbstractItemView *view, QObj
 {
 }
 
-CustomFieldsListDelegate::~CustomFieldsListDelegate()
-{
-}
+CustomFieldsListDelegate::~CustomFieldsListDelegate() = default;
 
 QWidget *CustomFieldsListDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &item, const QModelIndex &index) const
 {
