@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -15,9 +15,7 @@ ContactSelectTypeComboboxTest::ContactSelectTypeComboboxTest(QObject *parent)
 {
 }
 
-ContactSelectTypeComboboxTest::~ContactSelectTypeComboboxTest()
-{
-}
+ContactSelectTypeComboboxTest::~ContactSelectTypeComboboxTest() = default;
 
 void ContactSelectTypeComboboxTest::shouldHaveDefaultValue()
 {
