@@ -22,7 +22,7 @@ class MailListWidget : public QWidget
     Q_OBJECT
 public:
     explicit MailListWidget(QWidget *parent = nullptr);
-    ~MailListWidget();
+    ~MailListWidget() override;
     void loadContact(const KContacts::Addressee &contact);
     void storeContact(KContacts::Addressee &contact) const;
     void setReadOnly(bool readOnly);
