@@ -10,8 +10,8 @@
 #pragma once
 
 #include "contacteditor_private_export.h"
+#include <KContacts/Addressee>
 #include <editor/widgets/contacteditorcombobox.h>
-#include <kcontacts/addressee.h>
 namespace ContactEditor
 {
 /**
@@ -32,7 +32,7 @@ public:
     /**
      * Destroys the phone type combo.
      */
-    ~PhoneComboBoxType();
+    ~PhoneComboBoxType() override;
 
     /**
      * Sets the phone number @p type that shall be selected.
