@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -53,9 +53,7 @@ PersonalEditorWidget::PersonalEditorWidget(QWidget *parent)
     mainLayout->setRowStretch(2, 1);
 }
 
-PersonalEditorWidget::~PersonalEditorWidget()
-{
-}
+PersonalEditorWidget::~PersonalEditorWidget() = default;
 
 void PersonalEditorWidget::loadContact(const KContacts::Addressee &contact)
 {
