@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ PreferredLineEditWidgetTest::PreferredLineEditWidgetTest(QObject *parent)
 {
 }
 
-PreferredLineEditWidgetTest::~PreferredLineEditWidgetTest()
-{
-}
+PreferredLineEditWidgetTest::~PreferredLineEditWidgetTest() = default;
 
 void PreferredLineEditWidgetTest::shouldHaveDefaultValue()
 {
